@@ -1,7 +1,7 @@
 tv.mono <- function(refl, write = FALSE, filename='monotypic-D.dbf', nr.member = 1, tv_home, ...)
 {
- if(missing(tv_home)) tv_home <- vegdata:::tv.home()
- taxa <- vegdata:::load.taxlist(refl = refl, verbose = TRUE, syn = FALSE)   
+ if(missing(tv_home)) tv_home <- tv.home()
+ taxa <- load.taxlist(refl = refl, verbose = TRUE, syn = FALSE)   
  AG <- table(taxa$IsChildTaxonOfID)
  AG <- AG[AG == nr.member]
  AG <- as.integer(names(AG))
@@ -15,7 +15,6 @@ MEMB_NAME=taxa$TaxonName[match(AG,taxa$IsChildTaxonOfID)], MEMB_taxonRank=taxa$t
 # mono$AGG_taxonRank[i] <- as.character(taxa[taxa$IsChildTaxonOfID == AG[i],7])
 # }
 if(write) {
-  require(foreign)
   write.dbf(mono, filename) } else 
 return(mono)
 }
